API Reference
=============

.. toctree::
   :maxdepth: 1

   bayestar
   command
   distance
   eigenframe
   healpix_tree
   io/events
   io/fits
   io/hdf5
   kde
   moc
   plot/index
   postprocess/contour
   postprocess/detector_frame
   postprocess/ellipse
   postprocess/find_injection
   postprocess/util
   util/file
   util/numpy
   util/sqlite
